@import "theme.css";

.login-card {
    min-height: 100vh;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
    margin: 0 auto;
    background: url("/static/login.avif");
    background-position: center;
    background-repeat: no-repeat;
    background-size: cover;
    padding: 30px 12px;
}

[data-bs-theme="dark"] .login-card {
    background: none;
}

.login-card .logo {
    display: block;
    text-align: center;
    max-width: 200px;
    margin: auto;
    margin-bottom: 30px;
}

.img-fluid {
    max-width: 100%;
    height: auto;
}

.login-card .login-main {
    width: 450px;
    padding: 30px;
    border-radius: 10px;
    -webkit-box-shadow: 0 0 37px rgba(8, 21, 66, 0.05);
    box-shadow: 0 0 37px rgba(8, 21, 66, 0.05);
    margin: 0 auto;
    background-color: var(--dh-sidebar-background);
}

.login-card .login-main .theme-form h4 {
    margin-bottom: 5px;
}

.login-card .login-main .theme-form p {
    margin-bottom: 25px;
    color: #898989;
}

.login-card .login-main .theme-form .form-group {
    margin-bottom: 10px;
    position: relative;
}

.login-card .login-main .theme-form label {
    font-size: 14px;
}

.btn-light {
    background-color: rgb(9 0 102 / 6%) !important;
    border-color: rgb(9 0 102 / 6%) !important;
}

.btn-showcase{
    display: flex;
    align-items: center;
    flex-wrap: wrap;
    justify-content: center;
    gap: 20px;
}

.btn-showcase .btn{
    width: 40%;
}

.btn{
    padding: 12px;
}

.password_field input,
.password_field input:focus{
    padding-right: 20% !important;
}

.password_field .show-hide{
    position: absolute;
    top: 30%;
    right: 7%;
    cursor: pointer;
}

[data-bs-theme="dark"] .login-card .logo img {
    filter: brightness(0) invert(1);
}
