{% load admin_list dashub i18n %}

<div class="dh-actions pagination-dh-actions">
    <div class="row">
        <div class="col-5">
            <div class="dataTables_info" role="status" aria-live="polite">
                {{ cl.result_count }}
                {% if cl.result_count == 1 %}
                    {{ cl.opts.verbose_name }}
                {% else %}
                    {{ cl.opts.verbose_name_plural }}
                {% endif %}

                {% if cl.formset and cl.result_count %}
                    <input type="submit" name="_save" class="btn btn-sm btn-success" value="{% trans 'Save' %}">
                {% endif %}
            </div>
        </div>

        <div class="col-7">
            <ul class="pagination justify-content-end m-0">
                {% if pagination_required %}
                    {% for i in page_range %}
                        {% dashub_paginator_number cl i %}
                    {% endfor %}
                {% endif %}
            </ul>
        </div>
    </div>
</div>
