{% include "django/forms/widgets/input.html" %}
{% if widget.wrap_label %}
    <label{% if widget.attrs.id %} for="{{ widget.attrs.id }}"{% endif %} class="form-check-label"><span class="truncate">{{ widget.label }}</span></label>
{% endif %}
