{% extends "admin/base_site.html" %}
{% load i18n admin_urls static dashub %}

{% block content %}
    <style>
    header,
    .dh-sidebar,
    .page-header{
        display:none !important;
    }

    .dh-container{
        top:0;
        min-height:100vh;
        margin-left:0;
    }
    </style>
    <div class="row col-md-12">
        <div class="col-12">
            <ul class="timeline">
                {% for action in action_list reversed %}
                    <li class="timeline-item">
                        <div class="timeline-body">
                            <div class="timeline-meta">
                                <span>{{ action.action_time|date:"DATETIME_FORMAT" }}</span>
                            </div>
                            <div class="timeline-content timeline-indicator">
                                {% action_message_to_list action as action_message_list %}
                                {% for action_message in action_message_list %}
                                    <div class="{{ action_message.colour }}">
                                        <h6 class="mb-1">{{ action_message.msg|style_bold_first_word }}</h6>
                                        <span class="text-secondary fs-7">User: <a class="text-secondary fs-7"
                                                                                   href="{% jazzy_admin_url action.user request.current_app|default:"admin" %}"
                                                                                   target="_blank">{{ action.user.get_username }}
                                            {% if action.user.get_full_name %} ({{ action.user.get_full_name }}
                                                ){% endif %}</a></span>
                                    </div>
                                {% endfor %}
                            </div>
                        </div>
                    </li>
                {% endfor %}
            </ul>
        </div>
    </div>

{% endblock %}
