@charset "UTF-8";

@import "theme.css";

body {
    --bs-body-font-family: "Roboto", serif;
    font-size: 15px;
    --form-control-width: 250px;
}

@media (max-width: 800px) {
    body {
        --form-control-width: 200px;
    }
}

a {
    text-decoration: none !important;
    color: var(--primary);
}

.text-header {
    color: var(--bs-heading-color)
}

.bg-body {
    background: var(--bs-body-bg)
}

.bg-light-primary {
    background: #edf2ff;
    color: #4680ff
}

.icon-svg-primary {
    fill: #edf2ff;
    stroke: #4680ff
}

.bg-light-secondary {
    background: #eff0f2;
    color: #5b6b79
}

.icon-svg-secondary {
    fill: #eff0f2;
    stroke: #5b6b79
}

.bg-light-success {
    background: #eaf6f2;
    color: #2ca87f
}

.icon-svg-success {
    fill: #eaf6f2;
    stroke: #2ca87f
}

.bg-light-warning {
    background: #fcf3e6;
    color: #e58a00
}

.icon-svg-warning {
    fill: #fcf3e6;
    stroke: #e58a00
}

.bg-light-light {
    background: #fefeff;
    color: #f8f9fa
}

.icon-svg-light {
    fill: #fefeff;
    stroke: #f8f9fa
}

.font-light {
    font-weight: 300 !important
}

.text-md {
    font-size: .8125rem !important
}

.text-lg {
    font-size: 1rem !important
}

:focus {
    outline: 0
}

a:hover {
    outline: 0;
    text-decoration: none
}

a:not([href]) {
    color: inherit
}

p {
    font-size: 16px
}

.h1,
.h2,
.h3,
.h4,
.h5,
.h6,
h1,
h2,
h3,
h4,
h5,
h6 {
    color: var(--dh-heading-color)
}

b {
    font-weight: 600
}

.btn-page .btn {
    margin-right: 5px;
    margin-bottom: 5px
}

@media (min-width: 1600px) {
    .container {
        max-width: 1540px
    }
}

.media {
    display: flex
}

.media .media-body {
    flex-grow: 1
}

.dh-sidebar {
    background: var(--dh-sidebar-background);
    width: 280px;
    position: fixed;
    top: 0;
    bottom: 0;
    z-index: 1026;
    overflow: hidden;
    box-shadow: var(--dh-sidebar-shadow);
    border-right: var(--dh-sidebar-border)
}

.dh-sidebar .navbar-wrapper {
    width: 280px;
    background: inherit
}

.dh-sidebar ul {
    list-style: none;
    padding-left: 0;
    margin-bottom: 0
}

.dh-sidebar .dh-caption {
    color: var(--dh-sidebar-caption-color);
    display: block;
    padding: 24px 14px 8px !important;
    text-transform: uppercase;
    position: relative;
    line-height: 1.2;
    font-size: 13px;
    font-weight: 600;
}

.dh-sidebar .dh-caption:first-child {
    padding-top: 10px !important
}

.dh-sidebar .dh-caption:first-child::after {
    display: none
}

.dh-sidebar .dh-caption i,
.dh-sidebar .dh-caption svg {
    display: none
}

.dh-sidebar .dh-caption label {
    margin-bottom: 0;
}

.dh-sidebar .dh-caption span:not(.badge) {
    display: block;
    color: #67758a;
    font-size: 14px;
    font-weight: 500
}

.dh-sidebar .dh-micon {
    margin-right: 10px;
    height: 15px;
    width: 15px;
    display: inline-block;
    vertical-align: middle;
    text-align: center
}

.dh-sidebar .dh-micon i {
    font-size: 15px;
    vertical-align: super
}

.dh-sidebar .dh-micon > svg {
    width: 22px;
    height: 22px;
    display: inline-block
}

.dh-sidebar .dh-link {
    display: block;
    padding: 13px 15px;
    color: var(--dh-sidebar-color);
    position: relative;
    font-size: 14px;
    font-weight: 400
}

.dh-sidebar .dh-link.active,
.dh-sidebar .dh-link:focus,
.dh-sidebar .dh-link:hover {
    text-decoration: none
}

.dh-sidebar .dh-navbar > .dh-item {
    margin: 0 10px
}

.dh-sidebar .dh-navbar > .dh-item > .dh-link::after {
    content: "";
    border-radius: var(--bs-border-radius);
    position: absolute;
    top: 2px;
    right: 2px;
    left: 2px;
    bottom: 2px;
    opacity: .1
}

.dh-sidebar .dh-navbar > .dh-item.active > .dh-link {
    font-weight: 500;
    color: var(--primary)
}

.dh-sidebar .dh-navbar > .dh-item.active > .dh-link:after {
    background: var(--primary)
}

.dh-sidebar .dh-navbar > .dh-item:not(.active):hover > .dh-link:after {
    background: var(--dh-sidebar-color)
}

.dh-sidebar .dh-navbar .dh-submenu .dh-link:hover {
    color: var(--primary)
}

.dh-sidebar .dh-navbar > .dh-item .dh-submenu {
    position: relative;
}

.dh-sidebar .dh-navbar > .dh-item .dh-submenu:before {
    position: absolute;
    content: "";
    width: 1px;
    background: rgba(203, 204, 206, 0.57);
    top: 6px;
    left: 27px;
    height: calc(100% - 12px);
    -webkit-transition: height 0.5s;
    transition: height 0.5s;
}

.dh-sidebar .dh-navbar > .dh-item .dh-submenu li a:before {
    position: absolute;
    content: "";
    width: 5px;
    height: 5px;
    top: 50%;
    -webkit-transform: translateY(-50%);
    transform: translateY(-50%);
    left: 43px;
    border-radius: 100%;
    background: rgba(203, 204, 206, 0.57);
}

.dh-sidebar .dh-navbar > .dh-item .dh-submenu li a:after {
    position: absolute;
    content: "";
    top: 48%;
    width: 16px;
    border-top: 1px solid rgba(203, 204, 206, 0.57);
    left: 27px;
}

.dh-sidebar .dh-navbar > .dh-item .dh-submenu li a {
    padding: 12px 60px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    position: relative;
}

.dh-sidebar .dh-navbar > .dh-item .dh-submenu li a.active {
    color: var(--primary);
}

.dh-sidebar .dh-navbar > .dh-item .dh-submenu .dh-item.active > .dh-link {
    font-weight: 500
}

.dh-sidebar .dh-arrow {
    float: right;
    transition: all .2s ease-in-out;
    font-size: 20px;
    line-height: 20px;
}

.dh-sidebar .dh-arrow > svg {
    width: 14px;
    height: 14px
}

.dh-sidebar .dh-badge {
    margin-right: 5px;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    color: #fff;
    width: 20px;
    height: 20px;
    border-radius: 50%;
    font-size: 10px;
    line-height: 1;
    float: right;
    background: var(--primary)
}

.dh-sidebar .m-header {
    height: 74px;
    display: flex;
    align-items: center;
    padding: 16px 24px;
    justify-content: center;
}

.dh-sidebar .m-header .b-brand img {
    height: auto;
    width: 200px;
}

.dh-sidebar .navbar-content {
    position: relative;
    height: calc(100vh - 74px);
    padding: 10px 0;
    overflow: hidden scroll
}

.dh-sidebar .card {
    box-shadow: var(--bs-card-box-shadow);
    margin: 15px
}

.dh-sidebar .card.dh-user-card {
    margin: 0 15px 15px;
    box-shadow: none;
    background: var(--dh-sidebar-user-background)
}

.dh-user-card img {
    width: 50px;
    height: auto;
}

.dh-sidebar .card.dh-user-card .card-body {
    padding: 10px;
}

.dh-sidebar .dh-hasmenu:not(.menu-open) > .dh-submenu {
    display: none
}

.dh-sidebar .dh-hasmenu .dh-arrow i {
    transition: transform 0.2s linear;
}

.dh-sidebar .dh-hasmenu.open-menu .dh-arrow i {
    transform: rotate(90deg);
    transition: transform 0.2s linear;
}

.dh-menu-overlay {
    position: fixed;
    top: 0;
    left: 0;
    width: 100vw;
    height: 100vh;
    z-index: 1;
    -webkit-backdrop-filter: blur(3px);
    backdrop-filter: blur(3px);
    background: rgba(0, 0, 0, .15)
}

[data-dh-sidebar-caption=false] .dh-sidebar .dh-caption {
    display: none
}

@media (min-width: 1025px) {
    .navbar-overlay .dh-sidebar:not(.dh-over-menu-active) {
        left: -280px;
        box-shadow: none
    }

    .dh-sidebar {
        transition: width .2s ease
    }

    .dh-sidebar ~ .dh-header {
        transition: left .2s ease
    }

    .dh-sidebar ~ .dh-container,
    .dh-sidebar ~ .dh-footer {
        transition: margin-left .2s ease
    }

    .dh-sidebar-hide .dh-sidebar {
        width: 0;
        --dh-sidebar-border: none
    }

    .dh-sidebar-hide .dh-sidebar ~ .dh-header {
        left: 0
    }

    body .dh-actions,
    body .dh-header {
        left: 280px;
    }

    .dh-sidebar-hide .dh-sidebar ~ .dh-container,
    .dh-sidebar-hide .dh-sidebar ~ .dh-footer {
        margin-left: 0
    }

    .dh-sidebar-hide .dh-header {
        left: 0;
    }

    .dh-header .dh-h-item.dh-sidebar-popup {
        display: none
    }
}

@media (max-width: 1024px) {
    .dh-header .dh-h-item.dh-sidebar-collapse {
        display: none
    }

    .dh-sidebar {
        left: -280px;
        box-shadow: none;
        background: var(--bs-body-bg);
        top: 0;
        transition: all .2s ease-in-out
    }

    .dh-sidebar.mob-sidebar-active {
        left: 0
    }

    .dh-sidebar.mob-sidebar-active .navbar-wrapper {
        position: relative;
        z-index: 5;
        background: inherit
    }
}

.dh-actions,
.dh-header {
    background: var(--dh-header-background);
    color: var(--dh-header-color);
    min-height: 74px;
    box-shadow: var(--dh-header-shadow);
    -webkit-backdrop-filter: blur(4px);
    backdrop-filter: blur(4px);
    position: fixed;
    left: 0;
    right: 0;
    z-index: 1025;
    display: flex;
    transition: 0.2s all;
}

.dh-header {
    border-bottom: 1px dashed var(--dh-sidebar-border-color);
}

.dh-actions {
    bottom: 0;
    min-height: 60px;
    border-top: 1px dashed var(--dh-sidebar-border-color);
    padding: 10px 25px 10px 25px;
    transition: 0.2s all;
}

.pagination-dh-actions {
    width: calc(100% - 280px) !important;
}

.change-list-actions-row .pagination {
    margin: 0;
}

.dh-actions.hide {
    transform: translateY(100%);
}

.dh-actions .select2-container--default {
    min-width: 200px;
}

.dh-header ul {
    margin-bottom: 0;
    display: inline-flex
}

.dh-header .m-header {
    height: 74px;
    display: flex;
    align-items: center;
    justify-content: space-between;
    width: 280px;
    padding: 16px 10px 16px 24px
}

.dh-header .header-wrapper {
    display: flex;
    padding: 0 25px;
    flex-grow: 1
}

@media (max-width: 576px) {
    .dh-header .header-wrapper {
        padding: 0 15px
    }
}

.dh-header .dh-h-item {
    min-height: 74px;
    display: flex;
    align-items: center;
    position: relative
}

.dh-header .dh-head-link {
    margin: 0 4px;
    position: relative;
    font-weight: 500;
    padding: 0;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    width: 44px;
    height: 44px;
    border-radius: 8px;
    color: var(--dh-header-color);
    overflow: hidden
}

.dh-header .dh-head-link::before {
    content: "";
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    z-index: 1;
    background: var(--dh-active-background);
    border-radius: 50%;
    transform: scale(0);
    transition: all 80ms cubic-bezier(.37, .24, .53, .99)
}

.dh-header .dh-head-link > i,
.dh-header .dh-head-link > svg {
    position: relative;
    z-index: 5;
    color: var(--dh-header-color);
    transition: all 80ms cubic-bezier(.37, .24, .53, .99)
}

.dh-header .dh-head-link > i {
    font-size: 24px
}

.dh-header .dh-head-link > svg {
    width: 24px;
    height: 24px
}

.dh-header .dh-head-link.active,
.dh-header .dh-head-link:active,
.dh-header .dh-head-link:focus,
.dh-header .dh-head-link:hover {
    text-decoration: none;
    color: var(--dh-header-color)
}

.dh-header .dh-head-link.active > i,
.dh-header .dh-head-link.active > svg,
.dh-header .dh-head-link:active > i,
.dh-header .dh-head-link:active > svg,
.dh-header .dh-head-link:focus > i,
.dh-header .dh-head-link:focus > svg,
.dh-header .dh-head-link:hover > i,
.dh-header .dh-head-link:hover > svg {
    color: var(--dh-header-color);
    transform: scale(1.08)
}

.dh-header .dh-head-link.active::before,
.dh-header .dh-head-link:active::before,
.dh-header .dh-head-link:focus::before,
.dh-header .dh-head-link:hover::before {
    border-radius: 0;
    transform: scale(1)
}

.dh-header .dh-head-link .dh-h-badge {
    position: absolute;
    top: 2px;
    right: 2px;
    border-radius: 50%;
    font-size: 9px;
    z-index: 9
}

.dh-header .dh-h-dropdown {
    transform: none !important;
    top: 100% !important
}

.dh-header .dh-h-dropdown.dropdown-menu-end {
    right: 0 !important;
    left: auto !important
}

.dh-header .user-avatar {
    width: 42px;
    border-radius: 100%;
    z-index: 1;
}

.dh-header .header-user-profile .dh-head-link {
    width: auto;
    padding: 7px;
    background: 0 0
}

.dh-header .header-user-profile .dh-head-link:focus .user-avatar,
.dh-header .header-user-profile .dh-head-link:hover .user-avatar {
    transform: scale(1.03)
}

.dh-header .header-user-profile .dh-head-link:focus::before,
.dh-header .header-user-profile .dh-head-link:hover::before {
    display: none
}

.dh-header .header-user-profile .dh-head-link > span > i {
    font-size: 22px;
    margin-right: 8px
}

.dh-header .header-user-profile .dh-head-link .user-avatar {
    width: 35px;
    transition: all 80ms cubic-bezier(.37, .24, .53, .99)
}

@media (max-width: 576px) {
    .dh-header .header-user-profile .dh-head-link {
        width: 40px
    }

    .dh-header .header-user-profile .dh-head-link .user-avatar {
        margin-right: 0
    }

    .dh-header .header-user-profile .dh-head-link > span,
    .dh-header .header-user-profile .dh-head-link > span > i {
        display: none
    }
}

.dh-header .dropdown-user-profile {
    min-width: 352px;
    max-width: 100%
}

.dh-header .dropdown-user .dropdown-menu {
    min-width: var(--form-control-width);
    max-width: 100%;
    padding: 15px;
    overflow-y: auto;
}

.dh-header .dropdown-user .dropdown-menu::-webkit-scrollbar {
    display: none;
}

.dh-header .dropdown-user .dropdown-menu {
    scrollbar-width: none;
}

.dh-header .dropdown-user .dropdown-menu {
    -ms-overflow-style: none;
}

.dh-header .dropdown-user-profile .dropdown-body,
.dh-header .dropdown-user-profile .dropdown-header {
    padding: 16px 20px
}

.dh-header .dropdown-user-profile .dropdown-item {
    padding: 10px 15px;
    display: flex;
    border-radius: var(--bs-border-radius);
    align-items: center;
    justify-content: space-between;
    border: var(--bs-border-width) var(--bs-border-style) transparent
}

.dh-header .dropdown-user-profile .dropdown-item:focus,
.dh-header .dropdown-user-profile .dropdown-item:hover {
    color: var(--bs-dropdown-link-color);
    background: var(--dh-active-background);
    border-color: var(--bs-border-color)
}

@media (max-width: 576px) {
    .dh-header .dropdown-user-profile {
        min-width: calc(100% - 30px)
    }
}

.dh-header .dropdown-notification {
    min-width: 450px;
    max-width: 100%
}

.dh-header .dropdown-notification .dropdown-body,
.dh-header .dropdown-notification .dropdown-header {
    padding: 16px 20px
}

.dh-header .dropdown-notification .badge {
    font-size: .8125rem;
    padding: .43em 1em
}

.dh-header .dropdown-notification .user-avatar {
    display: flex;
    align-items: center;
    justify-content: center;
    width: 40px;
    height: 40px;
    font-size: 20px
}

.dh-header .dropdown-notification .card {
    cursor: pointer
}

.dh-header .dropdown-notification .card:hover {
    background: var(--dh-active-background)
}

@media (max-width: 576px) {
    .dh-header .dropdown-notification {
        min-width: calc(100% - 30px)
    }
}

.dh-announcement-offcanvas {
    --bs-offcanvas-width: 474px
}

.dh-announcement-offcanvas .offcanvas-body::-webkit-scrollbar {
    width: 6px;
    opacity: 0
}

.dh-announcement-offcanvas .offcanvas-body::-webkit-scrollbar:hover {
    opacity: 1
}

.dh-announcement-offcanvas .offcanvas-body::-webkit-scrollbar-track {
    background: 0 0
}

.dh-announcement-offcanvas .offcanvas-body::-webkit-scrollbar-thumb {
    background: #e9ecef
}

.dh-announcement-offcanvas .offcanvas-body::-webkit-scrollbar-thumb:hover {
    background: #aeb9c5
}

@media (max-width: 1024px) {
    .dh-header {
        top: 0;
        left: 0;
        transition: all .15s ease-in-out
    }

    .dh-header .m-header {
        display: none
    }

    .dh-header.mob-header-active {
        top: 74px
    }

    .dh-header.mob-header-active .header-wrapper {
        background: var(dh-header-background);
        position: relative;
        z-index: 5
    }

    .dh-header .dh-md-overlay {
        position: fixed;
        top: 0;
        left: 0;
        width: 100vw;
        height: 100vh;
        z-index: 1;
        background: rgba(0, 0, 0, .2)
    }

    .dh-header .dh-mob-drp.mob-drp-active .dh-h-item {
        display: block;
        min-height: auto;
        position: relative
    }

    .dh-header .dh-mob-drp.mob-drp-active .dh-h-item .dh-head-link {
        display: block;
        margin: 5px 10px !important
    }

    .dh-header .dh-mob-drp.mob-drp-active .dh-h-item .dropdown-menu {
        position: relative !important;
        width: 100%;
        float: none;
        box-shadow: none
    }

    .dh-header .dh-mob-drp.mob-drp-active ul {
        display: block
    }
}

@media (max-width: 576px) {
    .dh-header .dh-head-link {
        padding: .65rem;
        margin: 0 5px
    }

    .dh-header .dh-h-item {
        position: static
    }

    .dh-header .dh-h-item .dh-h-dropdown {
        left: 15px !important;
        right: 15px !important
    }
}

.dh-footer {
    position: relative;
    z-index: 995;
    margin-left: 280px;
    margin-top: 74px;
    padding: 15px 0
}

.dh-footer a {
    color: var(--bs-body-color)
}

.dh-footer a:hover {
    color: var(--primary)
}

.dh-footer .footer-wrapper {
    padding-left: 40px;
    padding-right: 40px
}

@media (max-width: 1024px) {
    .dh-footer .footer-wrapper {
        padding-left: 30px;
        padding-right: 30px
    }
}

@media (max-width: 576px) {
    .dh-footer .footer-wrapper {
        padding-left: 15px;
        padding-right: 15px
    }
}

.dh-footer .footer-link .list-inline-item:not(:last-child) {
    margin-right: .9rem
}

@media (max-width: 1024px) {
    .dh-footer {
        margin-left: 0
    }
}

@media (max-width: 576px) {
    .dh-footer {
        margin-top: 50px
    }
}

.dh-container {
    position: relative;
    top: 74px;
    margin-left: 280px;
    min-height: calc(100vh - 135px)
}

.dh-container .dh-content {
    padding: 20px 25px 60px;
}

@media (max-width: 1200px) {
    .dh-container .dh-content.container {
        max-width: 100%
    }
}

.dh-container .page-header + .row {
    padding-top: 24px
}

.dh-container .page-header + .dh-content {
    padding-top: 85px
}

.page-header {
    display: flex;
    align-items: center;
    top: 74px;
    left: 280px;
    right: 0;
    z-index: 1023;
    min-height: 55px;
    padding: 13px 0;
    background: 0 0;
    border-radius: 8px
}

.page-header .page-block {
    width: 100%
}

.page-header .page-header-title {
    display: inline-block
}

.page-header .h5,
.page-header h5 {
    margin-bottom: 0;
    margin-right: 8px;
    padding-right: 8px;
    font-weight: 500
}

.page-header .breadcrumb {
    padding: 0;
    display: inline-flex;
    background: 0 0;
    font-size: 13px
}

.page-header .breadcrumb a {
    color: var(--bs-body-color)
}

.page-header .breadcrumb .breadcrumb-item a:hover {
    color: #4680ff
}

.page-header .breadcrumb .breadcrumb-item + .breadcrumb-item::before {
    position: relative;
    top: 2px
}

.page-header .breadcrumb .breadcrumb-item:last-child {
    opacity: .75
}

.page-header .breadcrumb svg {
    width: 14px;
    height: 14px;
    vertical-align: baseline
}

@media (max-width: 1024px) {
    .dh-container {
        margin-left: 0;
        margin-right: 0
    }

    .dh-container .page-header + .dh-content,
    .dh-container .page-header + .row,
    .dh-container .dh-content {
        padding-top: 20px;
        padding-left: 15px;
        padding-right: 15px
    }

    .page-header {
        position: relative;
        left: 0;
        top: 0;
        margin-left: 10px;
        margin-right: 10px
    }
}

@media (max-width: 576px) {
    .col-form-label {
        padding-top: 0;
        padding-bottom: 5px
    }

    .dh-container .dh-content {
        padding: 15px
    }

    .dh-container .container {
        padding-left: 0;
        padding-right: 0
    }

    .dh-container .page-header + .dh-content,
    .dh-container .page-header + .row {
        padding-left: 0;
        padding-right: 0
    }

    .page-header .h5,
    .page-header h5 {
        padding-bottom: 5px;
        margin-bottom: 0;
        border-right: none;
        font-size: 14px
    }

    .page-header .breadcrumb {
        display: flex;
        margin-bottom: 0;
        font-size: 11px
    }

    .page-header .text-md-right {
        margin-top: 5px
    }
}

.navbar-content {
    position: relative
}

[data-simplebar] {
    position: relative;
    flex-direction: column;
    flex-wrap: wrap;
    justify-content: flex-start;
    align-content: flex-start;
    align-items: flex-start
}

@media (min-width: 768px) {

    .footer-wrapper.container,
    .dh-content.container {
        max-width: 540px
    }
}

@media (min-width: 992px) {

    .footer-wrapper.container,
    .dh-content.container {
        max-width: 720px
    }
}

@media (min-width: 1200px) {

    .footer-wrapper.container,
    .dh-content.container {
        max-width: 960px
    }
}

@media (min-width: 1400px) {

    .footer-wrapper.container,
    .dh-content.container {
        max-width: 1140px
    }
}

.avatar {
    display: inline-flex;
    align-items: center;
    justify-content: center;
    border-radius: 8px;
    font-size: 18px;
    font-weight: 600;
    width: 48px;
    height: 48px
}

.avatar.avatar-icon {
    border: 2px solid var(--table-light-color)
}

.avatar.avatar-icon > img {
    width: 60%
}

.badge.dot {
    width: 6px;
    height: 6px;
    display: block;
    padding: 0
}

.badge.bg-light-primary {
    background: #edf2ff;
    color: #4680ff
}

.badge.bg-light-secondary {
    background: #eff0f2;
    color: #5b6b79
}

.badge.bg-light-success {
    background: #eaf6f2;
    color: #2ca87f
}

.badge.bg-light-warning {
    background: #fcf3e6;
    color: #e58a00
}

.badge.bg-light-light {
    background: #fefeff;
    color: #f8f9fa
}

.btn {
    font-size: 16px;
    min-height: var(--form-height);
}

.btn i {
    font-size: 20px;
    line-height: 20px;
}

.btn svg {
    width: 18px;
    height: 18px
}

.btn[class*=btn-light-],
.btn[class*=btn-link-] {
    box-shadow: none
}

.btn[class*=btn-outline-]:not(:hover) {
    box-shadow: none
}

.btn.btn-icon {
    display: inline-flex;
    align-items: center;
    justify-content: center;
    border-radius: 20px;
    font-size: 14px;
    font-weight: 600;
    padding: 0;
    width: 40px;
    height: 40px
}

.btn-check:active + .btn-light-theme,
.btn-check:checked + .btn-light-theme {
    background: #f36;
    color: #fff;
    border-color: #f36
}

.btn-check:active + .btn-link-theme,
.btn-check:checked + .btn-link-theme {
    background: #ffebf0;
    color: #f36;
    border-color: #ffebf0
}

.btn-check:active + .btn-link-hover-theme,
.btn-check:checked + .btn-link-hover-theme {
    background: #ffebf0;
    color: #f36;
    border-color: #ffebf0
}

.btn-light-primary {
    background: #edf2ff;
    color: #4680ff;
    border-color: #edf2ff
}

.btn-light-primary:hover {
    background: #4680ff;
    color: #fff;
    border-color: #4680ff
}

.btn-light-primary:focus {
    background: #4680ff;
    color: #fff;
    border-color: #4680ff
}

.btn-light-primary:not(:disabled):not(.disabled).active,
.btn-light-primary:not(:disabled):not(.disabled):active {
    background: #4680ff;
    color: #fff;
    border-color: #4680ff
}

.btn-check:active + .btn-light-primary,
.btn-check:checked + .btn-light-primary {
    background: #4680ff;
    color: #fff;
    border-color: #4680ff
}

.btn-link-primary {
    background: 0 0;
    color: #4680ff;
    border-color: transparent
}

.btn-link-primary:hover {
    background: #edf2ff;
    color: #4680ff;
    border-color: #edf2ff
}

.btn-link-primary:focus {
    background: #edf2ff;
    color: #4680ff;
    border-color: #edf2ff
}

.btn-link-primary:not(:disabled):not(.disabled).active,
.btn-link-primary:not(:disabled):not(.disabled):active {
    background: #edf2ff;
    color: #4680ff;
    border-color: #edf2ff
}

.btn-check:active + .btn-link-primary,
.btn-check:checked + .btn-link-primary {
    background: #edf2ff;
    color: #4680ff;
    border-color: #edf2ff
}

.btn-check:active + .btn-link-hover-primary,
.btn-check:checked + .btn-link-hover-primary {
    background: #edf2ff;
    color: #4680ff;
    border-color: #edf2ff
}

.btn-light-secondary {
    background: #eff0f2;
    color: #5b6b79;
    border-color: #eff0f2
}

.btn-light-secondary:hover {
    background: #5b6b79;
    color: #fff;
    border-color: #5b6b79
}

.btn-light-secondary:focus {
    background: #5b6b79;
    color: #fff;
    border-color: #5b6b79
}

.btn-light-secondary:not(:disabled):not(.disabled).active,
.btn-light-secondary:not(:disabled):not(.disabled):active {
    background: #5b6b79;
    color: #fff;
    border-color: #5b6b79
}

.btn-check:active + .btn-light-secondary,
.btn-check:checked + .btn-light-secondary {
    background: #5b6b79;
    color: #fff;
    border-color: #5b6b79
}

.btn-link-secondary {
    background: 0 0;
    color: #5b6b79;
    border-color: transparent
}

.btn-link-secondary:hover {
    background: #eff0f2;
    color: #5b6b79;
    border-color: #eff0f2
}

.btn-link-secondary:focus {
    background: #eff0f2;
    color: #5b6b79;
    border-color: #eff0f2
}

.btn-link-secondary:not(:disabled):not(.disabled).active,
.btn-link-secondary:not(:disabled):not(.disabled):active {
    background: #eff0f2;
    color: #5b6b79;
    border-color: #eff0f2
}

.btn-check:active + .btn-link-secondary,
.btn-check:checked + .btn-link-secondary {
    background: #eff0f2;
    color: #5b6b79;
    border-color: #eff0f2
}

.btn-check:active + .btn-link-hover-secondary,
.btn-check:checked + .btn-link-hover-secondary {
    background: #eff0f2;
    color: #5b6b79;
    border-color: #eff0f2
}

.btn-light-success {
    background: #eaf6f2;
    color: #2ca87f;
    border-color: #eaf6f2
}

.btn-light-success:hover {
    background: #2ca87f;
    color: #fff;
    border-color: #2ca87f
}

.btn-light-success:focus {
    background: #2ca87f;
    color: #fff;
    border-color: #2ca87f
}

.btn-light-success:not(:disabled):not(.disabled).active,
.btn-light-success:not(:disabled):not(.disabled):active {
    background: #2ca87f;
    color: #fff;
    border-color: #2ca87f
}

.btn-check:active + .btn-light-success,
.btn-check:checked + .btn-light-success {
    background: #2ca87f;
    color: #fff;
    border-color: #2ca87f
}

.btn-link-success {
    background: 0 0;
    color: #2ca87f;
    border-color: transparent
}

.btn-link-success:hover {
    background: #eaf6f2;
    color: #2ca87f;
    border-color: #eaf6f2
}

.btn-link-success:focus {
    background: #eaf6f2;
    color: #2ca87f;
    border-color: #eaf6f2
}

.btn-link-success:not(:disabled):not(.disabled).active,
.btn-link-success:not(:disabled):not(.disabled):active {
    background: #eaf6f2;
    color: #2ca87f;
    border-color: #eaf6f2
}

.btn-check:active + .btn-link-success,
.btn-check:checked + .btn-link-success {
    background: #eaf6f2;
    color: #2ca87f;
    border-color: #eaf6f2
}

.btn-check:active + .btn-link-hover-success,
.btn-check:checked + .btn-link-hover-success {
    background: #eaf6f2;
    color: #2ca87f;
    border-color: #eaf6f2
}

.btn-check:active + .btn-light-info,
.btn-check:checked + .btn-light-info {
    background: #3ec9d6;
    color: #fff;
    border-color: #3ec9d6
}

.btn-check:active + .btn-link-info,
.btn-check:checked + .btn-link-info {
    background: #ecfafb;
    color: #3ec9d6;
    border-color: #ecfafb
}

.btn-check:active + .btn-link-hover-info,
.btn-check:checked + .btn-link-hover-info {
    background: #ecfafb;
    color: #3ec9d6;
    border-color: #ecfafb
}

.btn-light-warning {
    background: #fcf3e6;
    color: #e58a00;
    border-color: #fcf3e6
}

.btn-light-warning:hover {
    background: #e58a00;
    color: #fff;
    border-color: #e58a00
}

.btn-light-warning:focus {
    background: #e58a00;
    color: #fff;
    border-color: #e58a00
}

.btn-light-warning:not(:disabled):not(.disabled).active,
.btn-light-warning:not(:disabled):not(.disabled):active {
    background: #e58a00;
    color: #fff;
    border-color: #e58a00
}

.btn-check:active + .btn-light-warning,
.btn-check:checked + .btn-light-warning {
    background: #e58a00;
    color: #fff;
    border-color: #e58a00
}

.btn-link-warning {
    background: 0 0;
    color: #e58a00;
    border-color: transparent
}

.btn-link-warning:hover {
    background: #fcf3e6;
    color: #e58a00;
    border-color: #fcf3e6
}

.btn-link-warning:focus {
    background: #fcf3e6;
    color: #e58a00;
    border-color: #fcf3e6
}

.btn-link-warning:not(:disabled):not(.disabled).active,
.btn-link-warning:not(:disabled):not(.disabled):active {
    background: #fcf3e6;
    color: #e58a00;
    border-color: #fcf3e6
}

.btn-check:active + .btn-link-warning,
.btn-check:checked + .btn-link-warning {
    background: #fcf3e6;
    color: #e58a00;
    border-color: #fcf3e6
}

.btn-check:active + .btn-link-hover-warning,
.btn-check:checked + .btn-link-hover-warning {
    background: #fcf3e6;
    color: #e58a00;
    border-color: #fcf3e6
}

.btn-check:active + .btn-light-danger,
.btn-check:checked + .btn-light-danger {
    background: #dc2626;
    color: #fff;
    border-color: #dc2626
}

.btn-check:active + .btn-link-danger,
.btn-check:checked + .btn-link-danger {
    background: #fce9e9;
    color: #dc2626;
    border-color: #fce9e9
}

.btn-check:active + .btn-link-hover-danger,
.btn-check:checked + .btn-link-hover-danger {
    background: #fce9e9;
    color: #dc2626;
    border-color: #fce9e9
}

.btn-light-light {
    background: #fefeff;
    color: #f8f9fa;
    border-color: #fefeff
}

.btn-light-light:hover {
    background: #f8f9fa;
    color: #fff;
    border-color: #f8f9fa
}

.btn-light-light:focus {
    background: #f8f9fa;
    color: #fff;
    border-color: #f8f9fa
}

.btn-light-light:not(:disabled):not(.disabled).active,
.btn-light-light:not(:disabled):not(.disabled):active {
    background: #f8f9fa;
    color: #fff;
    border-color: #f8f9fa
}

.btn-check:active + .btn-light-light,
.btn-check:checked + .btn-light-light {
    background: #f8f9fa;
    color: #fff;
    border-color: #f8f9fa
}

.btn-link-light {
    background: 0 0;
    color: #f8f9fa;
    border-color: transparent
}

.btn-link-light:hover {
    background: #fefeff;
    color: #f8f9fa;
    border-color: #fefeff
}

.btn-link-light:focus {
    background: #fefeff;
    color: #f8f9fa;
    border-color: #fefeff
}

.btn-link-light:not(:disabled):not(.disabled).active,
.btn-link-light:not(:disabled):not(.disabled):active {
    background: #fefeff;
    color: #f8f9fa;
    border-color: #fefeff
}

.btn-check:active + .btn-link-light,
.btn-check:checked + .btn-link-light {
    background: #fefeff;
    color: #f8f9fa;
    border-color: #fefeff
}

.btn-check:active + .btn-link-hover-light,
.btn-check:checked + .btn-link-hover-light {
    background: #fefeff;
    color: #f8f9fa;
    border-color: #fefeff
}

.btn-check:active + .btn-light-dark,
.btn-check:checked + .btn-light-dark {
    background: #212529;
    color: #fff;
    border-color: #212529
}

.btn-check:active + .btn-link-dark,
.btn-check:checked + .btn-link-dark {
    background: #e9e9ea;
    color: #212529;
    border-color: #e9e9ea
}

.btn-check:active + .btn-link-hover-dark,
.btn-check:checked + .btn-link-hover-dark {
    background: #e9e9ea;
    color: #212529;
    border-color: #e9e9ea
}

.dropdown-toggle.arrow-none:after {
    display: none
}

.dh-header .dropdown-menu {
    animation: .3s ease-in-out 0s normal forwards;
}

@keyframes fadein {
    from {
        transform: translate3d(0, 8px, 0);
        opacity: 0
    }

    to {
        transform: translate3d(0, 0, 0);
        opacity: 1
    }
}

.dropdown .dropdown-item {
    display: flex;
    align-items: center
}

.dropdown .dropdown-item.active,
.dropdown .dropdown-item:active,
.dropdown .dropdown-item:focus,
.dropdown .dropdown-item:hover {
    background: var(--dh-active-background);
    color: var(--bs-dropdown-link-color)
}

.dropdown-menu {
    box-shadow: 0 4px 24px 0 rgba(62, 57, 107, .18);
    border: none;
    padding: 8px
}

.dropdown-menu .dropdown-item {
    border-radius: 8px;
    padding: 10px 15px
}

.dropdown-menu .dropdown-item i {
    font-size: 22px;
    margin-right: 10px;
    height: auto;
    width: auto;
}

.card {
    box-shadow: var(--dh-card-box-shadow);
    margin-bottom: 12px;
    transition: box-shadow .2s ease-in-out
}

.card .card-header .h5,
.card .card-header h5 {
    margin-bottom: 0;
    font-size: .875rem;
    font-weight: 600
}

.card .card-header .h5 + .small,
.card .card-header .h5 + p,
.card .card-header .h5 + small,
.card .card-header h5 + .small,
.card .card-header h5 + p,
.card .card-header h5 + small {
    margin-top: 10px
}

.card .card-header .h5 + .small:last-child,
.card .card-header .h5 + p:last-child,
.card .card-header .h5 + small:last-child,
.card .card-header h5 + .small:last-child,
.card .card-header h5 + p:last-child,
.card .card-header h5 + small:last-child {
    margin-bottom: 0
}

.card .card-header .card-header-right {
    right: 10px;
    top: 10px;
    float: right;
    padding: 0;
    position: absolute
}

@media only screen and (max-width: 575px) {
    .card .card-header .card-header-right {
        display: none
    }
}

.card .card-header .card-header-right .dropdown-menu {
    margin-top: 0
}

.card .card-header .card-header-right .dropdown-menu li {
    cursor: pointer
}

.card .card-header .card-header-right .dropdown-menu li a {
    font-size: 14px;
    text-transform: capitalize
}

.card .card-header .card-header-right .btn.dropdown-toggle {
    border: none;
    background: 0 0;
    box-shadow: none;
    color: #888
}

.card .card-header .card-header-right .btn.dropdown-toggle i {
    margin-right: 0
}

.card .card-header .card-header-right .btn.dropdown-toggle:after {
    display: none
}

.card .card-header .card-header-right .btn.dropdown-toggle:focus {
    box-shadow: none;
    outline: 0
}

.card .card-header .card-header-right .btn.dropdown-toggle {
    border: none;
    background: 0 0;
    box-shadow: none;
    padding: 0;
    width: 20px;
    height: 20px;
    right: 8px;
    top: 8px
}

.card .card-header .card-header-right .btn.dropdown-toggle.mobile-menu span {
    background-color: #888;
    height: 2px;
    border-radius: 5px
}

.card .card-header .card-header-right .btn.dropdown-toggle.mobile-menu span:after,
.card .card-header .card-header-right .btn.dropdown-toggle.mobile-menu span:before {
    border-radius: 5px;
    height: 2px;
    background-color: #888
}

.card .card-footer {
    transition: box-shadow .2s ease-in-out
}

.card:hover .card-footer[class*=bg-] {
    box-shadow: none
}

@media (max-width: 576px) {
    .card {
        margin-bottom: 20px
    }

    .card .card-header {
        padding: 20px
    }

    .card .card-header .h5,
    .card .card-header h5 {
        font-size: .875rem
    }

    .card .card-body {
        padding: 20px
    }
}

.form-check label {
    cursor: pointer
}

.form-check label input {
    cursor: pointer
}

.form-check-input.f-12 {
    margin-left: -2.9em
}

body input[type=checkbox],
body input[type=radio] {
    width: 1em;
    height: 1em;
    margin-top: .25em;
    vertical-align: top;
    background-color: var(--checkbox-bg);
    background-repeat: no-repeat;
    background-position: center;
    background-size: contain;
    border: 1px solid rgba(0, 0, 0, .25);
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    -webkit-print-color-adjust: exact;
    color-adjust: exact;
    margin-right: 5px;
    border-radius: 3px;
}

body input[type=checkbox]:focus,
body input[type=radio]:focus {
    box-shadow: 0 0 0 0.25rem rgba(var(--primary-rgb), 0.25);
}

body input[type=radio] {
    border-radius: 50%;
}

body input[type=checkbox]:checked,
body input[type=radio]:checked,
body .form-check-input.input-primary:checked {
    border-color: var(--primary);
    background-color: var(--primary);
}

body input:checked[type=radio] {
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3e%3ccircle r='2' fill='%23fff'/%3e%3c/svg%3e");
}

body input:checked[type=checkbox] {
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 20 20'%3e%3cpath fill='none' stroke='%23fff' stroke-linecap='round' stroke-linejoin='round' stroke-width='3' d='M6 10l3 3l6-6'/%3e%3c/svg%3e");
}

.i-main .i-block {
    display: inline-flex;
    align-items: center;
    justify-content: center;
    width: 70px;
    height: 70px;
    margin: 5px;
    border: 1px solid var(--table-light-color);
    border-radius: var(--bs-border-radius);
    position: relative;
    cursor: pointer
}

.i-main .i-block i {
    font-size: 30px
}

.i-main .i-block label {
    margin-bottom: 0;
    display: none
}

.dh-icon-checkbox {
    position: relative;
    padding: 0
}

.dh-icon-checkbox .dh-icon-check {
    display: none
}

.dh-icon-checkbox .form-check-input {
    position: absolute;
    z-index: 9;
    margin-left: 0;
    left: 3px;
    top: 2px;
    opacity: 0;
    cursor: pointer;
    font-size: 20px
}

.dh-icon-checkbox .form-check-input:checked ~ .dh-icon-uncheck {
    display: none
}

.dh-icon-checkbox .form-check-input:checked ~ .dh-icon-check {
    display: inline-block
}

.offer-check-block {
    overflow-x: auto;
    overflow-y: hidden;
    display: flex;
    flex-wrap: nowrap;
    align-items: center;
    justify-content: flex-start
}

.offer-check-block::-webkit-scrollbar {
    height: 6px;
    opacity: 0
}

.offer-check-block::-webkit-scrollbar:hover {
    opacity: 1
}

.offer-check-block::-webkit-scrollbar-track {
    background: 0 0
}

.offer-check-block::-webkit-scrollbar-thumb {
    background: #e9ecef
}

.offer-check-block::-webkit-scrollbar-thumb:hover {
    background: #aeb9c5
}

.offer-check {
    overflow: visible;
    position: relative;
    width: 180px;
    flex: 0 0 auto;
    margin: 10px
}

.offer-check .form-check-label::after {
    content: "";
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    border-radius: var(--bs-border-radius)
}

.offer-check .form-check-input {
    position: relative;
    z-index: 8;
    float: right
}

.offer-check .form-check {
    padding-left: 0;
    margin-bottom: 0
}

.offer-check .form-check .form-check-input:checked + .form-check-label::after {
    background: rgba(var(--bs-primary-rgb), .1);
    box-shadow: 0 8px 24px rgba(27, 46, 94, .12), inset 0 0 0 2px rgba(var(--bs-primary-rgb), .5)
}

@keyframes _26Tc6u {
    0% {
        transform: translateZ(0) scale(0)
    }

    40% {
        transform: translateZ(0) scale(1.2)
    }

    to {
        transform: translateZ(0) scale(1)
    }
}

@keyframes _3d25CI {
    0% {
        transform: translateZ(0) scale(0);
        opacity: 1
    }

    to {
        transform: translateZ(0) scale(1);
        opacity: 0
    }
}

@keyframes r9OBmc {
    0% {
        opacity: 0
    }

    50% {
        opacity: 1
    }

    to {
        opacity: 0
    }
}

@keyframes _18Xo9B {
    to {
        transform: translate3d(22px, -4px, 0)
    }
}

@keyframes _3z13ic {
    to {
        transform: translate3d(14px, 4px, 0) scale(.7)
    }
}

@keyframes _33IoP_ {
    to {
        transform: translate3d(-4px, 22px, 0)
    }
}

@keyframes _2D5htx {
    to {
        transform: translate3d(4px, 18px, 0) scale(.7)
    }
}

@keyframes _3TtatR {
    to {
        transform: translate3d(-22px, -4px, 0)
    }
}

@keyframes _3UC1np {
    to {
        transform: translate3d(-18px, 4px, 0) scale(.7)
    }
}

@keyframes u9Mhrv {
    to {
        transform: translate3d(-4px, -22px, 0)
    }
}

@keyframes _2ERa1V {
    to {
        transform: translate3d(4px, -18px, 0) scale(.7)
    }
}

@keyframes pulseWarning {
    0% {
        border-color: #f90
    }

    to {
        border-color: #e58a00
    }
}

div:where(.swal2-container) div:where(.swal2-radio),
div:where(.swal2-container) input:where(.swal2-input),
div:where(.swal2-container) label:where(.swal2-checkbox) {
    margin: .4em 0 0 !important
}

div:where(.swal2-container) input:where(.swal2-file) {
    margin: 1em auto 3px !important
}

div:where(.swal2-icon) {
    margin: 1.5em auto .6em !important
}

div:where(.swal2-container) button:where(.swal2-close):focus {
    box-shadow: none !important
}

.card {
    --bs-card-border-color: var(--table-light-color);
}

[data-bs-theme="dark"] .card {
    --bs-card-border-color: var(--bs-border-color);
}

.dropdown-user-profile .dropdown-body,
.offcanvas-body {
    overflow: hidden scroll;
}

.header_search_form {
    position: relative;
    margin: 0 15px 15px;
}

.header_search_form i {
    position: absolute;
    top: 27%;
    left: 12px;
    font-size: 20px;
    line-height: 20px;
    color: var(--dh-sidebar-color);
}

.header_search_form input {
    padding: 10px 10px 10px 40px !important;
}

.form-control:not([type=submit]),
.form-control:not([type=submit]):focus {
    padding: 10px 15px;
    background-color: var(--body-bg);
}

.form-select:not(.is-invalid):focus,
.form-control:not(.is-invalid):not([type=submit]):focus {
    border-color: var(--primary);
    box-shadow: 0 0 0 .25rem rgba(var(--primary-rgb), .25);
}

.form-select.is-invalid:focus,
.form-control.is-invalid:focus {
    border-color: rgb(255, 0, 0);
    box-shadow: 0 0 0 .25rem rgba(255, 0, 0, .25);
}

.form-control::-moz-placeholder {
    color: #bbb;
}

.form-control::placeholder {
    color: #bbb;
}

.required {
    color: red;
}

.card-title {
    font-weight: 500;
    text-align: center;
    font-size: 16px;
    margin: 0;
    padding: 6px;
}

.card-title p {
    margin-bottom: 0;
}

ul {
    padding-left: 15px;
    margin-top: 5px;
}

.card .card-header,
.card .card-footer {
    padding: 10px 15px;
    font-weight: 600;
    font-size: 16px;
    background: rgba(var(--primary-rgb), 0.05);
}

.card .card-footer {
    font-weight: 500;
}

.card-danger h4 {
    font-size: 16px;
}

.form-check {
    font-size: 17px;
    margin-bottom: 10px;
}

.card {
    background-color: var(--body-bg);
}

.categories_card .card-body {
    max-height: 300px;
    overflow: hidden scroll;
}

.select2-container--default .select2-selection--single .select2-selection__arrow {
    width: 30px;
}

.select2-container--default .select2-selection--multiple,
.select2-container .select2-selection--single,
.select2-dropdown,
.select2-container--default .select2-search--dropdown .select2-search__field {
    border-color: var(--bs-border-color) !important;
    border-radius: var(--bs-border-radius) !important;
}

body .select2-container--default .select2-selection--multiple .select2-selection__choice {
    padding: 3px 3px 3px 20px;
    border-color: var(--bs-border-color);
    background: var(--bs-border-color);
    margin-left: 7px;
    margin-top: 7px;
}

.select2-container--default .select2-selection--multiple .select2-selection__choice__remove {
    height: 100%;
    padding: 0 8px !important;
}

body .select2-container--default .select2-selection--multiple .select2-selection__choice__display {
    padding-left: 13px;
}

body .select2-container .select2-search--inline .select2-search__field {
    height: 25px;
}

body .select2-container--default .select2-selection--single .select2-selection__rendered {
    line-height: 46px;
    color: var(--bs-body-color);
}

.select2-container--default .select2-results__option[aria-selected=true] {
    background-color: #f3f3f3;
}

.select2-container--default .select2-results__option--highlighted[aria-selected] {
    background-color: var(--primary);
}

.select2-results__option {
    padding: 10px 6px;
}

.select2-results__option:last-child {
    border-bottom-left-radius: 4px;
    border-bottom-right-radius: 4px;
}

.select2-container--default .select2-search--dropdown .select2-search__field {
    padding: 7px;
    border-radius: 4px;
}

.select2-container .select2-selection--single .select2-selection__rendered {
    padding-left: 12px;
    padding-right: 26px;
}

.form-control {
    font-size: inherit;
    min-height: 40px;
}

.empty_placeholder {
    min-height: 150px;
    border: 3px dashed #d5d5d5;
    display: flex;
    align-items: center;
    justify-content: center;
    flex-direction: column;
    width: 100%;
    border-radius: 5px;
    position: relative;
}

.empty_placeholder a {
    position: absolute;
    height: 100%;
    width: 100%;
    display: flex;
    justify-content: center;
    align-items: center;
}

body .image_picker_container.added .empty_placeholder {
    display: none;
}

body .image_fill_placeholder {
    position: relative;
}

body .image_fill_placeholder i {
    position: absolute;
    background: red;
    color: #fff;
    width: 25px;
    height: 25px;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 100%;
    right: 10px;
    top: 10px;
    cursor: pointer;
}

body .image_fill_placeholder img {
    width: 100%;
}

.b-brand img {
    width: 100%;
}

/**  =====================
  35. Data Tables css start
==========================  **/
.datatable-table > tbody > tr > td,
.datatable-table > tbody > tr > th,
.datatable-table > tfoot > tr > td,
.datatable-table > tfoot > tr > th,
.datatable-table > thead > tr > td,
.datatable-table > thead > tr > th {
    vertical-align: middle;
    padding: 0.7rem 0.75rem;
}

.datatable-table td,
.datatable-table th,
.table td,
.table th {
    border-top: 1px solid var(--table-light-color);
    border-bottom: none;
    white-space: nowrap;
    padding: 0.7rem 0.75rem;
    vertical-align: middle;
}

.datatable-table thead th,
.table thead th {
    border-bottom: 1px solid var(--table-light-color);
    font-size: 13px;
    color: var(--table-dark-color);
    background: transparent;
    text-transform: uppercase;
}

.datatable-table tbody + tbody,
.table tbody + tbody {
    border-top: 2px solid var(--table-light-color);
}

.datatable-table.table-dark thead th,
.table.table-dark thead th {
    background-color: #11171a;
}

.datatable-table.dataTable[class*=table-] thead th,
.table.dataTable[class*=table-] thead th {
    background: #f8f9fa;
}

.datatable-table > :not(:last-child) > :last-child > *,
.table > :not(:last-child) > :last-child > * {
    border-bottom-color: var(--table-light-color);
}

.datatable-table > :not(:first-child),
.table > :not(:first-child) {
    border-top: none;
}

/* Border versions */
.table-bordered {
    border: 1px solid var(--table-light-color);
}

.table-bordered td,
.table-bordered th {
    border: 1px solid var(--table-light-color);
}

/* Zebra-striping */
.table-striped tbody tr:nth-of-type(2n + 1) {
    background-color: rgba(70, 128, 255, 0.03);
}

/* Hover effect */
body table tbody tr.add-row:hover,
body .table-hover > tbody > tr.add-row:hover > *,
body .table-hover > tbody > tr:hover > * {
    background-color: transparent !important;
    --bs-table-color-state: transparent;
    --bs-table-bg-state: transparent;
}

/* Table backgrounds */
.table .thead-dark th {
    color: #fff;
    background-color: #212529;
    border-color: #0a0c0d;
}

.table-dark {
    color: #fff;
    background-color: #212529;
}

.table-dark td,
.table-dark th,
.table-dark thead th {
    border-color: #0a0c0d;
}

.table-dark.table-striped tbody tr:nth-of-type(odd) {
    background-color: #1c2023;
}

.table-dark.table-hover tbody tr:hover {
    background-color: #16181b;
}

.table-dark thead th {
    color: #fff;
}

/* fixed header position */
table.dataTable.fixedHeader-floating {
    top: calc(74px + 55px) !important;
}

@media screen and (max-width: 992px) {
    table.dataTable.fixedHeader-floating {
        display: none !important;
    }
}

@media screen and (max-width: 992px) {
    .fixedHeader-locked {
        display: none !important;
    }
}

/**======= basic table css start =======**/
.table.table-xl td,
.table.table-xl th {
    padding: 1.25rem 0.8rem;
}

.table.table-lg td,
.table.table-lg th {
    padding: 0.9rem 0.8rem;
}

.table.table-de td,
.table.table-de th {
    padding: 0.75rem 0.8rem;
}

.table.table-sm td,
.table.table-sm th {
    padding: 0.6rem 0.8rem;
}

.table.table-xs td,
.table.table-xs th {
    padding: 0.4rem 0.8rem;
}

/**======= basic table css end ======**/
table.dataTable > thead .sorting:before,
table.dataTable > thead .sorting:after,
table.dataTable > thead .sorting_asc:before,
table.dataTable > thead .sorting_asc:after,
table.dataTable > thead .sorting_desc:before,
table.dataTable > thead .sorting_desc:after,
table.dataTable > thead .sorting_asc_disabled:before,
table.dataTable > thead .sorting_asc_disabled:after,
table.dataTable > thead .sorting_desc_disabled:before,
table.dataTable > thead .sorting_desc_disabled:after {
    top: 13px;
}

table.dataTable tbody > tr > .selected td.select-checkbox:after,
table.dataTable tbody > tr > .selected th.select-checkbox:after,
table.dataTable tbody > tr.selected td.select-checkbox:after,
table.dataTable tbody > tr.selected th.select-checkbox:after {
    margin-top: -21px;
    margin-left: -7px;
}

.datatable-top {
    padding: 0 4px 14px;
}

.datatable-top > div {
    margin: 0 0 5px;
}

.datatable-bottom {
    padding: 14px 4px 0;
}

.card.table-card .datatable-top {
    padding-top: 0;
}

.card.table-card .datatable-top,
.card.table-card .datatable-bottom {
    padding-left: var(--bs-card-spacer-x);
    padding-right: var(--bs-card-spacer-x);
}

.datatable-top > nav:first-child,
.datatable-top > div:first-child {
    float: left;
}

.datatable-bottom > nav:first-child,
.datatable-bottom > div:first-child {
    float: left;
}

.datatable-top > nav:last-child,
.datatable-top > div:last-child {
    float: right;
}

@media (max-width: 575px) {
    .datatable-top > div:last-child {
        float: left;
        width: 100%;
    }
}

.datatable-bottom > nav:last-child,
.datatable-bottom > div:last-child {
    float: right;
}

.dataTable-dropdown label {
    display: flex;
    align-items: center;
    width: 230px;
    white-space: nowrap;
}

.dataTable-dropdown label select {
    margin-right: 8px;
}

.dataTable-info {
    margin: 7px 0;
}

/* PAGER */
.dataTable-pagination ul {
    margin: 0;
    padding-left: 0;
}

.dataTable-pagination li {
    list-style: none;
    float: left;
}

.dataTable-pagination a {
    border: 1px solid transparent;
    float: left;
    margin-left: 2px;
    padding: 6px 12px;
    position: relative;
    text-decoration: none;
    border-radius: 8px;
    color: #131920;
}

.dataTable-pagination a:hover {
    background-color: var(--bs-primary-light);
    color: var(--primary);
}

.dataTable-pagination .active a {
    background-color: var(--primary);
    color: #fff;
    cursor: default;
}

.dataTable-pagination .active a:focus,
.dataTable-pagination .active a:hover {
    background-color: var(--primary);
    color: #fff;
    cursor: default;
}

.dataTable-pagination .ellipsis a {
    cursor: not-allowed;
}

.dataTable-pagination .disabled a {
    cursor: not-allowed;
    opacity: 0.4;
}

.dataTable-pagination .disabled a:focus,
.dataTable-pagination .disabled a:hover {
    cursor: not-allowed;
}

.dataTable-pagination .disabled a:focus,
.dataTable-pagination .disabled a:hover {
    cursor: not-allowed;
    opacity: 0.4;
}

.dataTable-pagination .pager a {
    font-weight: bold;
}

/* TABLE */
.dataTable-table > tbody > tr > td,
.dataTable-table > tbody > tr > th {
    vertical-align: middle;
}

.dataTable-table > tfoot > tr > td,
.dataTable-table > tfoot > tr > th {
    vertical-align: middle;
}

.dataTable-table > thead > tr > td {
    vertical-align: middle;
}

.dataTable-table > thead > tr > th {
    vertical-align: middle;
}

.dataTable-table th {
    vertical-align: middle;
}

.dataTable-table th a {
    text-decoration: none;
    color: inherit;
    padding-right: 16px;
}

.dataTable-sorter {
    display: inline-block;
    height: 100%;
    position: relative;
    width: 100%;
}

.dataTable-sorter::before,
.dataTable-sorter::after {
    content: "";
    height: 0;
    width: 0;
    position: absolute;
    right: 4px;
    border-left: 4px solid transparent;
    border-right: 4px solid transparent;
    opacity: 0.2;
}

.dataTable-sorter::before {
    border-top: 4px solid #000;
    bottom: 0;
}

.dataTable-sorter::after {
    border-bottom: 4px solid #000;
    border-top: 4px solid transparent;
    top: 0;
}

.asc .dataTable-sorter::after,
.desc .dataTable-sorter::before {
    opacity: 0.6;
}

.dataTables-empty {
    text-align: center;
}

.datatable-top::after,
.datatable-bottom::after {
    clear: both;
    content: " ";
    display: table;
}

.dt-responsive .dt-row {
    overflow: auto;
}

.dataTables_scrollHeadInner,
.dataTables_scrollFootInner {
    width: calc(100% - 6px) !important;
}

.dataTables_scrollBody::-webkit-scrollbar {
    width: 6px;
    opacity: 0;
}

.dataTables_scrollBody::-webkit-scrollbar:hover {
    opacity: 1;
}

.dataTables_scrollBody::-webkit-scrollbar-track {
    background: transparent;
}

.dataTables_scrollBody::-webkit-scrollbar-thumb {
    background: #e9ecef;
}

.dataTables_scrollBody::-webkit-scrollbar-thumb:hover {
    background: #aeb9c5;
}

table.dataTable tbody th.focus,
table.dataTable tbody td.focus {
    outline: 2px solid var(--primary);
}

div.dt-autofill-handle {
    background: var(--primary);
}

table.dataTable {
    border-collapse: collapse !important;
    width: 100% !important;
}

table.dataTable .form-control,
table.dataTable .datatable-input,
table.dataTable .custom-select,
table.dataTable .dataTable-selector,
table.dataTable .dataTable-input {
    min-width: 100px;
    padding-right: 30px;
}

table.dataTable > tbody > tr.child ul.dtr-details {
    display: block;
}

#basic-scroller_wrapper .dataTables_paginate,
#state-scroller_wrapper .dataTables_paginate,
#api-scroller_wrapper .dataTables_paginate {
    padding-top: 5px;
}

@media (max-width: 462px) {
    .datatable-pagination {
        margin-top: 6px;
    }
}

@media (max-width: 462px) {

    .datatable-bottom > nav:last-child,
    .datatable-bottom > div:last-child {
        float: left;
    }
}

.table-striped > tbody > tr:nth-of-type(odd) > * {
    --bs-table-accent-bg: transparent;
}

.dataTables_length select.form-select,
.dataTables_length select.datatable-selector {
    padding-right: 30px;
}

@media screen and (max-width: 767px) {
    div.dataTables_wrapper div.dataTables_filter input {
        width: 155px;
    }
}

.dataTables_length,
.dataTables_filter {
    margin: 0 0 8px;
}


.course_group {
    display: flex;
    align-items: center;
    gap: 5px;
}

.course_group img {
    max-width: 100px;
    border-radius: 10px;
}

.course_group .title {
    font-weight: bold;
}

.dashboard .card.summary,
.dashboard .card.summary .card-header {
    background: #fff;
}

.dashboard .card.summary .card-header {
    border-bottom: 0;
}

.final_value {
    font-size: 2.5rem;
}

.dashboard .card.summary .text-light {
    color: #99A1B7 !important;
    font-weight: normal;
}

.dashboard .card.summary .bullet {
    width: 10px;
    height: 3px;
}

.dashboard .card.summary .bg-secondary {
    background: #99A1B7 !important;
}

.images_card_teacher_preview {
    display: flex;
    justify-content: center;
    align-items: center;
    gap: 10px;
}

.images_card_teacher_preview img {
    max-width: 50px;
    height: auto;
    border: 1px solid var(--bs-border-color);
    border-radius: 7px;
}

hr {
    color: #ccc;
}

.section_title {
    font-size: 1.2rem;
    color: #666;
    font-weight: normal;
}

.doc_single {
    width: 100%;
    height: 150px;
    position: relative;
    border-radius: 5px;
    margin-bottom: 20px;

    background-image: url(https://digitalgurkha.com/wp-content/plugins/tutor/assets/images/placeholder.svg);
    background-size: cover;
    background-repeat: no-repeat;
}

#documents .doc_single {
    max-width: 150px;
}

#documents .preview_docs {
    display: flex;
    gap: 20px;
}

.doc_name {
    width: 100%;
    position: absolute;
    bottom: 0;
    text-align: center;
    padding: 5px;
    background: #eee;
    color: #666;
}

.doc_close {
    position: absolute;
    width: 20px;
    height: 20px;
    background: #ff0000;
    display: flex;
    justify-content: center;
    align-items: center;
    color: #fff;
    border-radius: 100%;
    right: 5px;
    top: 5px;
}

.symbol {
    display: inline-block;
    flex-shrink: 0;
    position: relative;
    border-radius: .475rem;
}

.profile_card .name {
    font-size: 1.5rem !important;
    font-weight: normal !important;
    color: #000;
}


.profile_card .verified {
    max-width: 22px;
    height: auto;
    margin-left: 10px;
}

.profile_card .verified img {
    width: 100%;
    height: auto;
}

.text-hover-primary:hover {
    color: var(--primary) !important;
}

.profile_meta a {
    color: #99A1B7;
    font-weight: normal;
}

.profile_meta a i {
    margin-right: 5px;
}

.profile_progress_card {
    border: 1px dashed var(--bs-border-color);
    padding: 1rem;
    border-radius: 10px;
    margin-right: 1rem;
    min-width: 140px;
    text-align: center;
}

.profile_progress_card .counted {
    font-size: 1.5rem;
}

.profile_progress_card .label {
    color: #99A1B7;
}

.profile_card .symbol {
    max-width: 175px;
    height: auto;
}

.profile_card .symbol img {
    width: 100%;
    height: auto;
    border-radius: 10px;
}

.navprofile .nav-link {
    padding: 10px;
    font-size: 1rem;
    color: #99A1B7;
    border: 0 !important;
    outline: none;
    box-shadow: none;
}

.navprofile .nav-link.active,
.navprofile .nav-link:focus,
.navprofile .nav-link:hover,
.navprofile .nav-link:focus-visible {
    color: var(--primary);
    background: transparent;
    border-bottom: 2px solid var(--primary) !important;
    outline: none;
    box-shadow: none;
}

.navprofile {
    margin-top: 1.5rem;
}

.table > :not(caption) > * > * {
    background-color: transparent;
}

.btn-primary {
    --bs-btn-bg: var(--primary);
    --bs-btn-border-color: var(--primary);
    --bs-btn-hover-bg: var(--primary);
    --bs-btn-hover-border-color: var(--primary);
    --bs-btn-active-bg: var(--primary);
    --bs-btn-active-border-color: var(--primary);
    --bs-btn-disabled-bg: var(--primary);
    --bs-btn-disabled-border-color: var(--primary);
}

.callout {
    position: relative;
    padding: 1rem 1rem;
    margin-bottom: 1rem;
    border: 1px solid transparent;
    border-radius: .25rem;
}

.callout p {
    margin: 0 !important;
}

.callout-danger {
    color: #842029;
    background-color: #f8d7da;
    border-color: #f5c2c7;
}

.callout-danger p {
    color: #842029 !important;
}

.callout-success {
    color: #0f5132;
    background-color: #d1e7dd;
    border-color: #badbcc;
}

.callout-success p {
    color: #0f5132 !important;
}

#practet-actions:not(.dh-actions) > div {
    display: flex;
    justify-content: center;
    align-items: center;
    margin: 1rem 0;
    gap: 20px;
}

.dh-actions .row {
    width: 100%;
    align-items: center;
}

#practet-actions > div input {
    min-width: 100px;
    padding: 6px 10px;
}

.text-red,
.inline-deletelink {
    color: red !important;
}

.errorlist {
    margin-bottom: 0;
    list-style: none;
    padding: 0;
    margin-top: 4px;
}

.selector {
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: space-between;
}

.readonly {
    padding: 10px;
    border: 1px solid var(--bs-border-color);
    border-radius: 7px;
    color: #a5acb3;
}

body .field-permissions .related-widget-wrapper .select2 {
    display: none !important;
}

.help-block,
.timezonewarning {
    font-size: 14px;
    color: #859099;
    font-style: italic;
}

#changelist-search {
    display: flex;
    align-items: center;
    gap: 20px;
    flex-wrap: wrap;
}

.popupmodal iframe {
    width: 100%;
}

.popupmodal .modal-body {
    padding: 0;
}

#changelist-search .form-group {
    width: var(--form-control-width);
}

#changelist-search .form-group input,
#changelist-search .form-group select {
    min-height: 40px;
    padding: 5px 10px;
}

.alert .close {
    position: absolute;
    right: 13px;
    background: transparent;
    border: none;
    font-size: 25px;
    top: 0;
    height: 100%;
}

.alert .icon {
    background: var(--bs-alert-color);
    color: #fff;
    padding: 3px;
    border-radius: 100%;
    width: 18px;
    height: 18px;
    font-size: 10px;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    margin-right: 6px;
}

.djn-checkbox-select-all {
    width: 50px;
}

#result_list th,
#result_list th a {
    color: var(--bs-body-color);
    font-size: 15px;
    white-space: normal;
}

#result_list th {
    text-transform: capitalize;
}

#result_list th.field-email {
    text-transform: inherit;
}

#result_list thead {
    background-color: var(--table-light-color);
}

body .select2-container--default {
    min-width: 100%;
}

body #changelist-search .select2-container--default {
    min-width: var(--form-control-width);
}

body .select2-container--default .select2-selection--single {
    height: var(--form-height);
    border-color: var(--bs-border-color);
    background-color: inherit;
}

body .select2-container--default .selection {
    width: 100%;
}

body .select2-container--default .select2-selection--single .select2-selection__rendered {
    line-height: var(--form-height);
}

body .select2-container--default .select2-selection--single .select2-selection__arrow {
    height: var(--form-height);
    width: var(--form-height);
}

body .select2-container .select2-selection--single .select2-selection__rendered {
    padding-left: 15px;
}

body .select2-container--default .select2-results__option--highlighted.select2-results__option--selectable {
    background-color: var(--primary);
}

body .select2-dropdown,
body .select2-container--default .select2-search--dropdown .select2-search__field {
    border-color: var(--bs-border-color);
}

body .horizontal_tabs.card .card-body {
    padding: 0;
}

body .horizontal_tabs .card {
    border: none;
}

body .horizontal_tabs .card .card-body {
    border: none;
}

body .horizontal_tabs .card > .p-5 {
    padding: 1.5rem !important;
}

body .horizontal_tabs.card .nav-tabs {
    background-color: rgba(var(--primary-rgb), 0.05);
    margin-top: 0;
}

body .horizontal_tabs.card .nav-tabs .nav-link {
    padding: 15px;
    border-color: transparent !important;
    color: var(--bs-body-color);
}

body .horizontal_tabs.card .nav-tabs .nav-link.active {
    border: none;
}

body .horizontal_tabs.card .nav-tabs .nav-link:focus-visible {
    box-shadow: none !important;
}

p.datetime {
    font-size: 14px;
    color: #9b9b9b;
    display: flex;
    align-items: center;
    gap: 20px;
    margin-top: 10px;
}

p.datetime br {
    display: none;
}

.form-group {
    position: relative;
}

.related-lookup {
    position: absolute;
    top: 35px;
    right: 15px;
}

body.popup .dh-container {
    min-height: auto;
    position: static;
    padding-top: 0 !important;
}

body .popupmodal iframe {
    width: 100%;
    height: 450px;
}

body .popupmodal .modal-footer {
    border: none;
    padding: 0;
}

body.popup {
    padding-bottom: 100px;
}

body.popup #practet-actions {
    position: fixed;
    bottom: 0;
    left: 0;
    width: 100%;
    background: #fff;
    border-top: 1px solid var(--bs-border-color);
}

body .json-editor-blackbord {
    padding: 15px 30px;
    border-radius: 7px;
    background: #fff;
    border: 1px solid var(--bs-border-color);
    margin-top: 5px;
    color: #aaa;
}

body .json-property {
    color: #287d76;
}

body .json-editor-blackbord .json-dict {
    margin-left: 3px;
}

body .related-widget-wrapper a {
    display: inline-block;
    cursor: pointer;
    margin-right: 10px;
}

body .related-widget-wrapper {
    position: relative;
}

body .change_input_links {
    position: absolute;
    top: 12px;
    right: 35px;
    z-index: 99;
}

body .change_input_links img {
    width: 15px;
    height: 15px;
}

body .add-row .btn {
    float: right;
}

body .dashboard_card .avatar {
    --bs-bg-opacity: 0.05;
}

body .dashboard_card h3 {
    font-size: 20px;
}

body .dashboard_card .fa-circle {
    display: none;
}

body .current_password_remove_compulsary > span {
    display: none;
}

body #gallery-tab .column-order {
    width: 25%;
}

body .form-group:not(.search-form-input) input {
    margin: 3px 0;
}

body .inline-group .new-stacked .card-body,
body .inline-group .panel .card-body {
    padding: 1.5rem;
}

body .inline-group .new-stacked .inline-deletelink {
    padding-left: 1.5rem;
}

body .pagination {
    --bs-pagination-color: var(--primary);
    --bs-pagination-hover-color: var(--primary);
    --bs-pagination-focus-color: var(--primary);
    --bs-pagination-active-bg: var(--primary);
    --bs-pagination-active-border-color: var(--primary);
    --bs-pagination-focus-box-shadow: 0 0 0 0.25rem rgba(var(--primary-rgb), 0.25);
}

body .list-group {
    --bs-list-group-active-bg: var(--primary);
    --bs-list-group-active-border-color: var(--primary);
}

body .action_counter_list span {
    margin-right: 7px;
    border-right: 2px solid #e8e8e8;
    padding-right: 10px;
}

body .action_counter_list span:not(.hidden):last-child {
    border-right: none;
    padding-right: 0;
}

body .hidden {
    display: none;
}

body .row-form-errors .errorlist {
    margin-left: 40px;
    color: red;
}

body .vLargeTextField {
    max-height: calc(4.5em + .75rem + calc(var(--bs-border-width) * 2));
}

body .user_profile_card {
    display: flex;
    align-items: center;
    gap: 10px;
}

body .user_profile_card img {
    width: 50px;
    height: 50px;
    border-radius: 100%;
}

body .user_profile_card h5 {
    font-size: 16px;
    font-weight: 500;
    margin: 0;
}

body .user_profile_card p {
    font-size: 15px;
    font-weight: 400;
    margin: 0;
}

body .datetimeshortcuts {
    display: none !important;
}

body .empty-form {
    display: none !important;
}

body .form-control:disabled {
    opacity: 50%;
}

.alert-error {
    --bs-alert-color: var(--bs-danger-text-emphasis);
    --bs-alert-bg: var(--bs-danger-bg-subtle);
    --bs-alert-border-color: var(--bs-danger-border-subtle);
    --bs-alert-link-color: var(--bs-danger-text-emphasis);
}

.cursor-pointer {
    cursor: pointer;
}

.stacked-inline-group .panel .card.closed .card-header {
    border-radius: var(--bs-border-radius);
    border-bottom: none;
}

.stacked-inline-group .card {
    position: relative;
}

.stacked-inline-group .card .inline-deletelink {
    position: absolute;
    right: 15px;
    top: 15px;
    cursor: pointer;
}

.add-row {
    text-align: right;
    margin-top: 50px;
}

.add-row a.add-handler {

}

.stacked-inline-group .panel .card-body {
    border: 1px solid rgba(var(--primary-rgb), 0.05) !important;
    border-top: none !important;
    border-bottom-left-radius: var(--bs-border-radius);
    border-bottom-right-radius: var(--bs-border-radius);
}

.page-header .col-md-6:last-child {
    text-align: right;
}

.page_header_error_count {
    color: red;
    border: 2px solid red;
    width: 50px;
    height: 50px;
    border-radius: 100%;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    font-size: 16px;
    font-weight: bold;
    cursor: pointer;
}

.card.deleted {
    background: #fff8f8;
}

.card.deleted .card-header {
    text-decoration: line-through;
}

.nested-inline-group {
    padding: 1rem;
}

.djn-items .djn-item,
.djn-items .djn-inline-form {
    margin-bottom: 1rem;
}

body .djn-group-nested .djn-items .inline-related {
    border: 1px solid var(--bs-border-color);
    border-radius: var(--bs-border-radius);
}

.nested-inline-group .djn-item {
    border: 1px solid var(--bs-border-color);
    border-radius: var(--bs-border-radius);
}

.nested-inline-group h3,
.nested-inline-group h2 {
    font-size: 18px;
    margin-bottom: 12px;
    position: relative;
}

.form-group .help {
    font-size: 14px;
    font-style: italic;
    color: #908f8f;
}

.djn-item-content {
    padding: 1rem;
}

.nested-inline-group .djn-item .djn-drag-handler {
    padding: 1rem;
    background: var(--bs-border-color);
    font-size: 1rem;
    display: flex;
    align-items: center;
    justify-content: space-between;
    margin-bottom: 0;
    cursor: pointer;
}

.nested-inline-group .djn-item .djn-drag-handler .inline_label {
    font-weight: normal;
}

.grp-predelete {
    text-decoration: line-through;
    opacity: 50%;
}

.grp-predelete .djn-delete-handler label,
.grp-predelete .djn-delete-handler {
    cursor: pointer;
}

.djn-delete-handler input[type=checkbox] {
    display: none;
}

body .nested-placeholder,
body .djn-group .ui-sortable-placeholder {
    background: var(--bs-border-color) !important;
    border-style: dashed;
    border-color: var(--bs-border-color-translucent);
}

.form-group .required {
    position: relative;
    color: var(--bs-body-color);
}

.form-group .required:after {
    content: "*";
    color: red;
    margin-left: 5px;
}

.dh-sidebar .dh-micon {
    width: auto;
    height: 20px;
    line-height: 20px;
}

.dh-sidebar .dh-micon i {
    font-size: 20px;
}

.dh-sidebar .dh-navbar .dh-item .dh-link {
    display: flex;
    align-items: center;
}

.dh-sidebar .dh-navbar .dh-item.dh-hasmenu .dh-link {
    justify-content: space-between;
}

.gap-5px {
    gap: 5px;
}

.gap-6px {
    gap: 6px;
}

.gap-7px {
    gap: 7px;
}

.navbar-content.nomenu .dh-navbar {
    position: relative;
}

.navbar-content.nomenu .dh-navbar:before {
    content: "No Menus Found";
    text-align: center;
    display: flex;
    justify-content: center;
    align-items: center;
    color: #c3c8ce;
    margin-top: 2rem;
}

body .checkbox-row label {
    margin-left: 10px;
}

.tagify.form-control {
    padding: 4px;
}

body .tagify {
    --tags-focus-border-color: var(--primary);
    --tags-hover-border-color: var(--bs-border-color);
    --tags-disabled-bg: var(--bs-border-color);
    --tag-text-color: var(--bs-body-color);
    --tag-bg: var(--bs-border-color);
    --tag-hover: var(--bs-border-color);
    --tag-remove-btn-color: var(--bs-body-color);
    border-color: var(--bs-border-color);
}

.select2-container {
    --border-color: var(--bs-border-color);
    --body-quiet-color: var(--bs-border-color);
    --selected-bg: var(--primary);
    --primary-fg: #fff;
    --body-fg: #000;
    --body-bg: var(--bs-body-bg);
    width: 100% !important;
}

body .select2-container--default .select2-results__option--selected {
    background-color: var(--bs-body-bg);
}

body .select2-dropdown {
    border: 1px solid var(--bs-border-color);
    background: var(--bs-body-bg);
    color: var(--bs-body-color);
}

body .select2-container--admin-autocomplete .select2-results__option[aria-selected=true] {
    color: #fff;
}

body .select2-container--admin-autocomplete .select2-selection--single .select2-selection__arrow,
body .select2-container .select2-selection--single .select2-selection__rendered,
.select2-container--admin-autocomplete .select2-selection--single,
.select2-container--admin-autocomplete .select2-selection--multiple,
.select2-container .select2-selection--single,
.select2-container--default .select2-selection--single .select2-selection__arrow,
.select2-container .select2-selection--multiple {
    min-height: var(--form-height) !important;
}

body .select2-container--admin-autocomplete .select2-selection--single .select2-selection__rendered {
    padding: 8px 15px;
}

[data-bs-theme="dark"] .select2-container--admin-autocomplete .select2-selection--single .select2-selection__rendered,
[data-bs-theme="dark"] .select2-container--admin-autocomplete .select2-results > .select2-results__options {
    color: var(--bs-body-color);
}

body .select2-container .select2-selection--multiple .select2-selection__choice {
    padding: 3px 3px 3px 20px;
    border-color: var(--bs-border-color);
    background: var(--bs-border-color);
    margin-left: 7px;
    margin-top: 7px;
}

.select2-container .select2-selection--multiple .select2-selection__choice__remove {
    height: 100%;
    padding: 0 8px !important;
}

body .select2-container .select2-selection--multiple .select2-selection__choice__display {
    padding-left: 13px;
}

body .select2-container--admin-autocomplete .select2-selection--multiple .select2-selection__choice {
    padding: 3px 7px 3px 35px;
}

.select2-container .select2-selection--multiple .select2-selection__choice__remove {
    background-color: transparent;
    border: none;
    border-right: 1px solid #aaa;
    border-top-left-radius: 4px;
    border-bottom-left-radius: 4px;
    color: #999 !important;
    cursor: pointer;
    font-size: 1em;
    font-weight: bold;
    padding: 0 4px;
    position: absolute;
    left: 0;
    top: 0;
}

.select2-container--admin-autocomplete .select2-selection--multiple .select2-selection__rendered li {
    position: relative;
}

body fieldset.module .items .djn-module {
    margin-bottom: 1rem !important;
}

body .search-form-input i {
    position: absolute;
    top: 50%;
    right: 15px;
    font-size: 17px;
    transform: translateY(-50%);
    color: #8494a6;
}

body .search-form-input::placeholder {
    text-align: left;
    color: red;
}

#search_group span.small {
    font-size: 16px;
    margin-top: 5px;
    display: block;
}

.no_results {
    justify-content: center;
    display: flex;
    color: var(--dh-sidebar-border-color);
    font-size: 17px;
    min-height: 30vh;
    align-items: center;
}

.table-responsive {
    border: 1px solid var(--bs-border-color);
    border-radius: var(--bs-border-radius);
}

.table-responsive .table-bordered {
    border-style: hidden;
    margin-bottom: 0;
}

.btn-outline-secondary {
    --bs-btn-border-color: var(--bs-border-color);
    --bs-btn-hover-bg: var(--bs-border-color);
    --bs-btn-hover-border-color: var(--bs-border-color);
    --bs-btn-hover-color: #6c757d;
}

.submit-row {
    display: flex;
    align-items: center;
    margin-inline: auto;
    width: 100%;
    gap: 1rem;
}

.submit-row .submit-row-left {
    flex: 1;
    display: inline-flex;
    align-items: center;
    gap: 15px;
}

.btn-with-icon,
.filter-button,
.submit-row .btn,
.add-row .btn {
    display: inline-flex;
    align-items: center;
    justify-content: center;
    gap: 8px;
    text-transform: capitalize;
    min-height: var(--form-height);
    padding: 5px 12px;
}


/* Timeline css */
.timeline {
    list-style: none;
    margin: 0 10px;
    padding: 0;
    position: relative
}

.timeline:after {
    background-color: rgba(var(--primary-rgb), 0.3);
    bottom: 0;
    content: "";
    left: 0;
    margin-left: -1px;
    position: absolute;
    top: 0;
    width: 2px
}

@media (min-width: 768px) {
    .timeline:after {
        left: 33%
    }
}

.timeline > .timeline-item {
    margin: 0;
    padding: 0;
    position: relative
}

.timeline > .timeline-item:after {
    background: #fff;
    border: 2px solid var(--primary);
    border-radius: 50%;
    content: "";
    height: 16px;
    left: calc(8px * -1);
    position: absolute;
    top: calc(50% - 8px);
    width: 16px;
    z-index: 1
}

.timeline > .timeline-item .timeline-body {
    margin: 0;
    padding: 0;
    position: relative
}

.timeline > .timeline-item .timeline-meta {
    padding: 0 0 1rem 2rem
}

.timeline > .timeline-item:first-child .timeline-meta {
    padding: 2rem 0 1rem 2rem
}

.timeline > .timeline-item .timeline-content {
    padding: 0 0 2rem 2rem
}

.timeline > .timeline-item .timeline-content > div {
    margin-bottom: 1rem;
}

@media (min-width: 768px) {
    .timeline > .timeline-item {
        left: 33%;
        width: 67%
    }

    .timeline > .timeline-item .timeline-meta {
        display: flex;
        justify-content: flex-end;
        left: -100%;
        margin: 0;
        padding: 0 2rem 0 0;
        position: absolute;
        top: calc(50% - 10px);
        width: 100%;
        z-index: 1
    }

    .timeline > .timeline-item:first-child .timeline-meta {
        padding: 0 2rem 0 0
    }

    .timeline > .timeline-item .timeline-content {
        padding: 2rem
    }

    .timeline > .timeline-item .timeline-indicator {
        position: relative
    }

    .timeline > .timeline-item .timeline-indicator:after {
        border: 10px solid var(--bsb-tl-indicator-color);
        border-color: transparent var(--bsb-tl-indicator-color) transparent transparent;
        border-left-width: 0;
        content: "";
        left: calc(2rem - 10px);
        position: absolute;
        top: calc(50% - var(--bsb-tl-circle-offset));
        z-index: 1
    }
}

.timeline-content .danger h6 {
    color: #721c24;
}

.timeline-content .success h6 {
    color: #155724;
}

#modalHistory iframe {
    width: 100%;
    height: 100%;
}

#modalHistory .offcanvas-body {
    padding: 0;
}

.djn-items {
    counter-reset: item-counter;
}

.djn-items .djn-item:not(.djn-no-drag) h3:not(.inline-heading) {
    counter-increment: item-counter;
    position: relative;
    padding-left: 4rem;
}

.djn-items .djn-item:not(.djn-no-drag) h3:not(.inline-heading)::before {
    content: counter(item-counter);
    position: absolute;
    left: 0;
    top: 0;
    color: var(--bs-body-color);
    font-weight: bold;
    height: calc(100% - 10px);
    display: inline-flex;
    align-items: center;
    justify-content: center;
    width: 3rem;
    background: var(--bs-body-bg);
    border-radius: var(--bs-border-radius);
    margin-top: 5px;
    margin-left: 5px;
}

body .dh-actions {
    z-index: 1025;
}

body .change-list-actions-row {
    z-index: 1026;
}

body .offcanvas-backdrop {
    z-index: 1027;
}

body .offcanvas {
    --bs-offcanvas-zindex: 1028;
}

.form_label {
    font-weight: 500;
    font-size: 16px;
    margin-bottom: 10px;
    text-transform: capitalize;
    display: block;
}

#filtersOffcanvas .form-group {
    margin-bottom: 1.5rem;
}

#filtersOffcanvas .daterange .d-flex,
#filtersOffcanvas .datetime {
    gap: 10px;
}

#filtersOffcanvas .datetime .form-group {
    margin-bottom: 10px;
}

#filtersOffcanvas .offcanvas-footer {
    padding: 10px;
    border-top: 1px dashed var(--dh-sidebar-border-color);
}

#filtersOffcanvas .offcanvas-header {
    border-bottom: 1px dashed var(--dh-sidebar-border-color);
}

#filtersOffcanvas .offcanvas-footer .btn {
    width: 100%;
}

#filtersOffcanvas .form-check {
    padding-left: 0;
}

#filtersOffcanvas .form-check-label {
    margin-left: 10px;
}

.asteriskField {
    color: red !important;
    margin-left: 5px;
}

.clr-field {
    width: 100%;
}

.form-group-container {
    border: 1px solid #f0f0f0;
    border-radius: var(--bs-border-radius);
    margin-top: 2rem;
}

.form-group-container .group-title {
    background: #f0f0f0;
    border-top-left-radius: var(--bs-border-radius);
    border-top-right-radius: var(--bs-border-radius);
    padding: 1rem;
}

.form-group-container > div {
    padding: 0 1rem;
}

.dashboard_card ul {
    padding: 0;
    margin: 0;
    list-style: none;
}

.dashboard_card {
    height: 100%;
}

.dashboard_card .card-body {
    padding: 0;
}

.dashboard_card div a > div {
    display: flex;
    align-items: center;
    gap: 10px;
}

.dashboard_card div a > div .hgi {
    font-size: 20px;
}

.dashboard_card div a {
    display: flex;
    align-items: center;
    justify-content: space-between;
    padding: 10px 15px;
    border-bottom: 1px solid #f1f3f4;
    font-weight: 400 !important;
}

[data-bs-theme="dark"] .dashboard_card div a {
    border-color: var(--bs-border-color);
}

.dashboard_card div a:last-child {
    border-bottom: none;
}

.metric-icon {
    margin: 1rem;
}

.metric-icon i {
    font-size: 1.5rem;
    color: var(--bs-body-color);
}

.selector-chosen,
.selector-available {
    border: 1px solid var(--bs-border-color);
    border-radius: var(--bs-border-radius);
    display: flex;
    flex-direction: column;
    align-self: stretch;
}

.selector-chooser {
    list-style: none;
    padding: 0;
    flex-direction: column;
    font-size: 0;
    display: flex;
}

.selector-chooser button {
    font-family: "hugeicons-stroke-rounded", serif !important;
	font-style: normal;
	box-shadow: none;
	outline: none;
	padding: 10px 25px;
	border: none;
	background: none;
}

.selector-chooser .selector-add:before,
.selector-chooser .selector-remove:before{
    font-size: 16px;
}

.selector-chooser .selector-add:before {
    content: "㱭";
}

.selector-chooser .selector-remove:before {
    content: "㱏";
}

.selector .selector-available-title label,
.selector .selector-chosen-title label,
.selector .selector-chosen-title .helptext,
.selector .selector-available-title .helptext {
    border-bottom: 1px solid var(--bs-border-color);
    padding: 10px;
    font-weight: 500;
    width: 100%;
    font-size: 17px;
}

.selector .selector-chosen-title .helptext,
.selector .selector-available-title .helptext {
    font-weight: 400;
    font-size: 15px;
}

.list-footer-display,
.selector-chooseall,
.selector-clearall {
    width: 100%;
    border: none;
    outline: none;
    box-shadow: none;
    text-align: center;
    padding: 10px;
    border-top: 1px solid var(--bs-border-color);
    background: none;
    color: var(--primary);
}

.list-footer-display {
    color: inherit;
}

.selector select {
    background-image: none;
    flex-grow: 1;
    width: 100%;
    border: none;
    min-height: 200px;
}

.selector-filter input {
    width: 100%;
    padding: 10px;
    border: 1px solid var(--bs-border-color);
    border-radius: var(--bs-border-radius);
    margin-bottom: 10px;
}

.selector option {
    text-overflow: ellipsis;
    white-space: nowrap;
    padding-inline: 0.75rem;
    overflow: hidden;
}

.selector-filter {
    display: flex;
}

.selector-filter input {
    flex-grow: 1;
    margin: 0 10px !important;
}

[data-bs-theme="dark"] .dh-sidebar .m-header .b-brand img {
    filter: brightness(0) invert(1);
}

.tox:not(.tox-tinymce-inline).tox-tinymce--toolbar-sticky-on .tox-editor-header{
    top: 75px !important;
}