<input
    type="text"
    name="{{ widget.name }}"
    id="tag-input-{{ widget.name }}"
    value="{{ widget.value }}"
    class="form-control dashub_tag_input"
    {% include "django/forms/widgets/attrs.html" %}
>
