from __future__ import unicode_literals

from django.apps import AppConfig

__all__ = ["DashubConfig"]


class DashubConfig(AppConfig):
    name = "dashub"
    label = "dashub"
    verbose_name = "Dashub"
